<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr_RS">
<context>
    <name>ShowDesktop</name>
    <message>
        <location filename="../showdesktop.cpp" line="44"/>
        <source>Show desktop</source>
        <translation>Прикажи десктоп</translation>
    </message>
    <message>
        <location filename="../showdesktop.cpp" line="66"/>
        <source>Show Desktop: Global shortcut &apos;%1&apos; cannot be registered</source>
        <translation>Прикажи десктоп: Глобална пречица &apos;%1&apos; се не може регистровати</translation>
    </message>
    <message>
        <location filename="../showdesktop.cpp" line="51"/>
        <source>Show Desktop</source>
        <translation>Прикажи десктоп</translation>
    </message>
</context>
</TS>
